pub struct LogContextConfig {
pub keywords: Vec<String>,
pub context_lines: usize,
pub max_matches: usize,
pub case_sensitive: bool,
}Expand description
Configuration for extract_context.
Built with a fluent API; all setters consume and return Self.
Example
use sanitize_engine::log_context::LogContextConfig;
let config = LogContextConfig::new()
.with_extra_keywords(["timeout", "oomkilled"])
.with_context_lines(15)
.with_max_matches(100);Fields
keywords: Vec<String>Keywords to scan for. Each is matched as a substring of the line.
context_lines: usizeLines of context captured before and after each match.
max_matches: usizeMaximum number of matches to return before setting
LogContextResult::truncated.
case_sensitive: boolWhen true, keyword matching is case-sensitive. Default: false.
Implementations
Sourceimpl LogContextConfig
impl LogContextConfig
Sourcepub fn with_extra_keywords(
self,
extra: impl IntoIterator<Item = impl Into<String>>,
) -> Self
pub fn with_extra_keywords( self, extra: impl IntoIterator<Item = impl Into<String>>, ) -> Self
Merge additional keywords into the existing list without replacing defaults.
Sourcepub fn with_keywords(
self,
keywords: impl IntoIterator<Item = impl Into<String>>,
) -> Self
pub fn with_keywords( self, keywords: impl IntoIterator<Item = impl Into<String>>, ) -> Self
Replace all keywords with the given list.
Sourcepub fn with_context_lines(self, n: usize) -> Self
pub fn with_context_lines(self, n: usize) -> Self
Set how many lines of context to capture around each match.
Sourcepub fn with_max_matches(self, n: usize) -> Self
pub fn with_max_matches(self, n: usize) -> Self
Set the maximum number of matches to return.
Sourcepub fn case_sensitive(self, sensitive: bool) -> Self
pub fn case_sensitive(self, sensitive: bool) -> Self
Set case-sensitivity for keyword matching.