Module profile

Module profile 

File-type profiles for structured processors.

A FileTypeProfile tells the processing pipeline which processor to use and which fields/keys within the file should be sanitized.

Structs

FieldNameSignal
A field-name–based heuristic signal used during structured processing.
FieldRule
A rule describing a single field/key to sanitize.
FileTypeProfile
Specifies which processor to use and what fields to sanitize.

Constants

DEFAULT_FIELD_SIGNAL_THRESHOLD
Default Shannon entropy threshold (bits per character) for built-in field-name signals.