Module registry

Module registry 

Processor registry — discovers and dispatches structured processors.

The ProcessorRegistry holds a set of registered Processor implementations and provides methods to:

  1. Look up a processor by name.
  2. Auto-detect a processor for given content + profile.
  3. Process content using a matching processor, falling back to None if no processor matches (caller can then use the streaming scanner).

Structs

ProcessorRegistry
Registry of structured processors.