Module profile

Module profile 

File-type profiles for structured processors.

A FileTypeProfile tells the processing pipeline which processor to use and which fields/keys within the file should be sanitized.

Structs

FieldRule
A rule describing a single field/key to sanitize.
FileTypeProfile
Specifies which processor to use and what fields to sanitize.