Module xml_proc

Module xml_proc 

XML structured processor.

Uses quick-xml to parse and rewrite XML, preserving the document structure, attributes, and non-matched content.

Key Paths

Element paths are slash-separated: database/password. Attributes are expressed as element/@attr (e.g. connection/@host).

For simplicity this processor tracks the element stack and matches text content of elements and attribute values against field rules.

Structs

XmlProcessor
Structured processor for XML files.